=======
History
=======

0.1.1 (2017-07-25)
------------------

* Added `db.bind`
* API changed: parameter `conn` renamed to optional `bind`
* Delegated asyncpg Pool with `db.create_pool`
* Internal enhancement and bug fixes

0.1.0 (2017-07-21)
------------------

* First release on PyPI.
